@@ -18,6 +18,11 @@
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
+#' @param wls.target numeric vector indicating the spectral quantity values for
+#'   which wavelengths are to be searched and interpolated if need. The
+#'   \code{character} strings "half.maximum" and "half.range" are also accepted
+#'   as arguments. A list with \code{numeric} and/or \code{character} values is
+#'   also accepted.
 #' @param annotations a character vector
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
@@ -41,6 +46,7 @@ cps_plot <- function(spct,
                      pc.out,
                      label.qty,
                      span,
+                     wls.target,
                      annotations,
                      norm,
                      text.size,
@@ -112,6 +118,8 @@ cps_plot <- function(spct,
   }
 
   if (num.cps.cols > 1L) {
+    # remove raw_spct class before melting as it invalidates expectations
+    rmDerivedSpct(spct)
     spct <- tidyr::gather_(data = spct,
                            key_col = "scan",
                            value_col = "cps",
@@ -160,6 +168,7 @@ cps_plot <- function(spct,
                             annotations = annotations,
                             label.qty = label.qty,
                             span = span,
+                            wls.target = wls.target,
                             summary.label = cps.label,
                             text.size = text.size,
                             na.rm = TRUE)
@@ -189,7 +198,7 @@ cps_plot <- function(spct,
 #' @param object a cps_spct object.
 #' @param ... in the case of collections of spectra, additional arguments passed
 #'   to the plot methods for individual spectra, otherwise currently ignored.
-##' @param w.band a single waveband object or a list of waveband objects.
+#' @param w.band a single waveband object or a list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm).
 #' @param unit.out character IGNORED.
@@ -199,6 +208,11 @@ cps_plot <- function(spct,
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
+#' @param wls.target numeric vector indicating the spectral quantity values for
+#'   which wavelengths are to be searched and interpolated if need. The
+#'   \code{character} strings "half.maximum" and "half.range" are also accepted
+#'   as arguments. A list with \code{numeric} and/or \code{character} values is
+#'   also accepted.
 #' @param annotations a character vector ("summaries" is ignored).
 #' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
 #' @param tz character Time zone to use for title and/or subtitle.
@@ -229,6 +243,7 @@ autoplot.cps_spct <-
            pc.out = FALSE,
            label.qty = "mean",
            span = NULL,
+           wls.target = "HM",
            annotations = NULL,
            time.format = "",
            tz = "UTC",
@@ -256,6 +271,7 @@ autoplot.cps_spct <-
     cps_plot(spct = object, w.band = w.band, range = range,
              label.qty = label.qty,
              span = span,
+             wls.target = wls.target,
              pc.out = pc.out,
              annotations = annotations, norm = norm,
              text.size = text.size,
