@@ -4,12 +4,12 @@
 #' \code{geom_spct} is a special case of \code{geom_area}, where the minimum of
 #' the range is fixed to 0, but stacking is not enabled.
 #'
-#' An spectrum plot is the analog of a line plot (see \code{\link{geom_line}}),
-#' and can be used to show y varies over the range of x. The difference is that
+#' An spectrum plot is the analog of a line plot (see \code{\link[ggplot2]{geom_path}}),
+#' and can be used to show how y varies over the range of x. The difference is that
 #' the area under the line is filled.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
-#'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_string}}. Only needs
+#'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs
 #'   to be set at the layer level if you are overriding the plot defaults.
 #' @param data A data frame. If specified, overrides the default data frame
 #'   defined at the top level of the plot.
@@ -31,13 +31,12 @@
 #'   \code{\link[ggplot2]{layer}} for more details.
 #' @section Aesthetics: See \code{\link[ggplot2]{geom_ribbon}}
 #'
-#' @seealso \code{\link[ggplot2]{geom_area}} for stacked areas,
-#' \code{\link[ggplot2]{geom_line}} for lines (lines),
+#' @seealso \code{\link[ggplot2]{geom_ribbon}} for stacked areas,
+#' \code{\link[ggplot2]{geom_path}} for lines (lines),
 #' \code{\link[ggplot2]{geom_point}} for scatter plots.
 #'
 #' @examples
-#' library(ggplot2)
-#' library(photobiology)
+#'
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
 #' ggplot(sun.spct) + geom_spct()
 #'
@@ -65,7 +64,7 @@ geom_spct <- function(mapping = NULL, data = NULL, stat = "identity",
 #' @usage NULL
 #' @export
 GeomSpct <- ggproto("GeomSpct", GeomRibbon,
-  default_aes = aes(colour = NA, fill = "grey60", size = 0.5, linetype = 1,
+  default_aes = aes(color = NA, fill = "grey60", size = 0.5, linetype = 1,
     alpha = NA),
 
   required_aes = c("x", "y"),
