@@ -129,7 +129,7 @@ StatWbLabel <-
                        w.band <- waveband(x.range)
                      }
                      if (is.any_spct(w.band) ||
-                         (is.numeric(w.band) && length(na.omit(w.band)) >= 2)) {
+                         (is.numeric(w.band) && length(stats::na.omit(w.band)) >= 2)) {
                        w.band <- waveband(range(w.band, na.rm = TRUE))
                      }
                      if (!is.list(w.band) || is.waveband(w.band)) {
@@ -148,7 +148,7 @@ StatWbLabel <-
                                               wb.xmin = min(wb),
                                               wb.xmax = max(wb),
                                               wb.name = labels(wb)$label,
-                                              wb.color = color_of(wb, chroma.type = chroma.type),
+                                              wb.color = fast_color_of_wb(wb, chroma.type = chroma.type),
                                               BW.color = black_or_white(wb.color))
                          )
                      }
